@@ -1,3 +1,4 @@
+import numpy
 import imageio
 from io import BytesIO
 from typing import List, Tuple
@@ -34,6 +35,29 @@ def square(img: IMG) -> IMG:
                      (width + length) / 2, (height + length) / 2))
 
 
+def perspective(img: IMG, points: List[Tuple[float, float]]):
+    def find_coeffs(pa: List[Tuple[float, float]], pb: List[Tuple[float, float]]):
+        matrix = []
+        for p1, p2 in zip(pa, pb):
+            matrix.append([p1[0], p1[1], 1, 0,
+                           0, 0, -p2[0]*p1[0], -p2[0]*p1[1]])
+            matrix.append([0, 0, 0, p1[0],
+                           p1[1], 1, -p2[1]*p1[0], -p2[1]*p1[1]])
+        A = numpy.matrix(matrix, dtype=numpy.float32)
+        B = numpy.array(pb).reshape(8)
+        res = numpy.dot(numpy.linalg.inv(A.T * A) * A.T, B)
+        return numpy.array(res).reshape(8)
+
+    img_w, img_h = img.size
+    points_w = [p[0] for p in points]
+    points_h = [p[1] for p in points]
+    new_w = max(points_w) - min(points_w)
+    new_h = max(points_h) - min(points_h)
+    p = [(0, 0), (img_w, 0), (img_w, img_h), (0, img_h)]
+    coeffs = find_coeffs(points, p)
+    return img.transform((new_w, new_h), Image.PERSPECTIVE, coeffs, Image.BICUBIC)
+
+
 def save_gif(frames: List[IMG], duration: float) -> BytesIO:
     output = BytesIO()
     imageio.mimsave(output, frames, format='gif', duration=duration)
